@@ -1,6 +1,6 @@
-/*	$Id: kcgi.h,v 1.96 2017/03/12 06:01:29 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.99 2017/09/15 20:36:03 kristaps Exp $ */
 /*
- * Copyright (c) 2012, 2014, 2015, 2016 Kristaps Dzonsons <kristaps@bsd.lv>
+ * Copyright (c) 2012, 2014--2017 Kristaps Dzonsons <kristaps@bsd.lv>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -285,6 +285,7 @@ enum	kmime {
 	KMIME_APP_JAVASCRIPT,
 	KMIME_APP_JSON,
 	KMIME_APP_OCTET_STREAM,
+	KMIME_APP_PDF,
 	KMIME_IMAGE_GIF,
 	KMIME_IMAGE_JPEG,
 	KMIME_IMAGE_PNG,
@@ -481,6 +482,8 @@ void		 khttp_putc(struct kreq *, int);
 void		 khttp_puts(struct kreq *, const char *);
 int		 khttp_template(struct kreq *, 
 			const struct ktemplate *, const char *);
+int		 khttp_template_fd(struct kreq *, 
+			const struct ktemplate *, int, const char *);
 int		 khttp_template_buf(struct kreq *, 
 			const struct ktemplate *, const char *, 
 			size_t);
@@ -490,6 +493,9 @@ int		 khttp_templatex(const struct ktemplate *,
 int		 khttp_templatex_buf(const struct ktemplate *, 
 			const char *, size_t, 
 			const struct ktemplatex *, void *);
+int		 khttp_templatex_fd(const struct ktemplate *, 
+			int, const char *,
+			const struct ktemplatex *, void *);
 
 void		 khttp_write(struct kreq *, const char *, size_t);
 
